#!/usr/bin/php
<?php
/*
Exports Wunderlist 2 tasks as a plain text file
© 2013 Augusto Campos http://augustocampos.net/ (july 6, 2013)

Licensed under the Apache License, Version 2.0 (the "License"); 
you may not use this file except in compliance with the License. 
You may obtain a copy of the License at 
http://www.apache.org/licenses/LICENSE-2.0 

Unless required by applicable law or agreed to in writing, software 
distributed under the License is distributed on an "AS IS" BASIS, 
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
See the License for the specific language governing permissions and 
limitations under the License.
*/

global $dateformat;

// setup here:

// The location of a copy of your Wunderlist 2 database. It may be different
// for Mac and Windows machines. On the Mac, it may be different for users 
// that downloaded Wunderlist from the Mac App Store or from the site.
//
// Find your database location:  http://support.wunderlist.com/customer/portal/articles/59978-where-is-the-data-saved-on-the-device-in-wunderlist-
$dbfile=$_ENV["HOME"]."/Library/Containers/com.wunderkinder.wunderlistdesktop/Data/Library/Application Support/Wunderlist/WKModel.sqlite";	
// your timezone
date_default_timezone_set('GMT');						

// your date format
// US users should change to "n/j/Y" (month/day/year)
$dateformat="j/n/Y"; 									

// you should not need to change anything below this line


function detail($type,$s) {
	switch ($type) {
		case 1: 
			echo "\n$s\n";
			break;
		case 2: 
			echo "\t$s\n";
			break;
		case 3: 
			echo "\t>\t$s\n";
			break;
	}		
}

function convdate($dateint) {
	global $dateformat;
	if (!is_null($dateint)) return date($dateformat,strtotime("1/1/2001")+floor($dateint));
	else return "";
}

function _csv($type, array $a) {
	$delimiter = ';'; 
	$enclosure = '"';
	$fields=array();
	switch($type) {
		case 1:
			$fields[]=$a[ZTITLE];
			break;
		case 2:
		case 3:
			$fields[]="";
			if ($a[ZSTARRED]>0) $fields[]="X";
			else $fields[]="";
			if (!empty($a[ZCOMPLETEDAT])) $fields[]="X";
			else $fields[]="";
			if (3==$type) $a[ZTITLE] = "> ".$a[ZTITLE];
			$fields[]=$a[ZTITLE];
			$fields[]=convdate($a[ZCREATEDAT]);
			$fields[]=convdate($a[ZCOMPLETEDAT]);
			$fields[]=convdate($a[ZDUEDATE]);
			$fields[]=str_replace("\n","\r",$a[ZNOTE]);
			break;
	}
    $output = array();
    foreach ( $fields as $field ) {
        if ( preg_match( '/(;|"|\s)/', $field ) ) {
        	$field=preg_replace('/"/', "", $field);
            $output[] = '"' . $field . '"';
        }
        else {
            $output[] = $field;
        }
    }
    if (1==$type) echo "\n";
    echo implode( $delimiter, $output )."\n";
}

$ENT_GROUP=6;
$ENT_TASK=5;

$db = new SQLite3($dbfile);
_id();
echo "LIST;STAR;DONE;TITLE;CREATED;COMPLETED;DUE;NOTES\n";

$groups = $db->query("SELECT * FROM ZRESOURCE WHERE Z_ENT=$ENT_GROUP ORDER BY ZTITLE");
while ($tasklist = $groups->fetchArray()) {
	//detail(1,"$tasklist[Z_PK] $tasklist[ZTITLE]");  
	_csv(1,$tasklist);
	$tasks = $db->query("SELECT * FROM ZRESOURCE WHERE Z_ENT=$ENT_TASK AND ZTASKLIST=$tasklist[Z_PK] ORDER BY ZORDERINDEXDOUBLE");
	while ($task = $tasks->fetchArray()) {
		//detail(2,"$task[Z_PK]\t$star$task[ZTITLE] ".$deldate);  
		_csv(2,$task);
		$subtasks = $db->query("SELECT * FROM ZRESOURCE WHERE Z_ENT=$ENT_TASK AND ZPARENTTASK=$task[Z_PK] ORDER BY ZORDERINDEXDOUBLE");
		while ($subtask = $subtasks->fetchArray()) {
			//detail(3,"$subtask[Z_PK]\t$subtask[ZTITLE]");  
			_csv(3,$subtask);
		}	
	}	
	
}

function _id() {
	echo ";;;Tasks exported from Wunderlist 2\n";
	echo ";;;by export-wunderlist-tasks.php v.0.4\n";
	echo ";;;(c) 2013 Augusto Campos, available as open source code under an Apache 2.0 license\n";	
	echo ";;;http://efetividade.net/export-wunderlist\n";
	echo "\n";	
}


?>